
#ifndef _C14_co681_
#define _C14_co681_

#ifdef __cplusplus
extern "C" {
#endif

extern void F744_11649(EIF_REFERENCE);
extern void F744_11650(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit681(void);

#ifdef __cplusplus
}
#endif

#endif
